@@ -1,9 +1,19 @@
 from .AutoFix.AutoFix import AutoFix
 from .DependencyUpgrade.DependencyUpgrade import DependencyUpgrade
+from .GenerateDiagram.GenerateDiagram import GenerateDiagram
 from .GenerateDocstring.GenerateDocstring import GenerateDocstring
 from .GenerateREADME.GenerateREADME import GenerateREADME
+from .GenerateUnitTests.GenerateUnitTests import GenerateUnitTests
 from .PRReview.PRReview import PRReview
 from .ResolveIssue.ResolveIssue import ResolveIssue
-from .GenerateUnitTests.GenerateUnitTests import GenerateUnitTests
 
-__all__ = ["AutoFix", "DependencyUpgrade", "GenerateREADME", "PRReview", "ResolveIssue", "GenerateDocstring", "GenerateUnitTests"]
+__all__ = [
+    "AutoFix",
+    "DependencyUpgrade",
+    "GenerateREADME",
+    "PRReview",
+    "ResolveIssue",
+    "GenerateDocstring",
+    "GenerateUnitTests",
+    "GenerateDiagram",
+]
